@@ -25,4 +25,4 @@ def init_database(url, echo=False):  # pragma: nocover
 
 
 # Import your model modules here.
-from owl_dev.database.model import Status, Info  # noqa  # isort:skip
+from owl_dev.database.model import Info  # noqa  # isort:skip
